@@ -1,9 +1,9 @@
 from mainwindow import SASImageGuiMain
-import gtk
-
+from gi.repository import Gtk
+from gi.repository import GObject
 __all__ = ['SASImageGuiMain', 'sasimagegui_main']
 
 def sasimagegui_main():
     mw = SASImageGuiMain()
     mw.show_all()
-    gtk.main()
+    Gtk.main()
