@@ -1,16 +1,21 @@
-import gtk
+from gi.repository import Gtk
 import os
-import gobject
+from gi.repository import GObject
 
-from ..PyGTKCallback import PyGTKCallback
 from sastool import misc
 from .. import patheditor
 from sastool import classes
 
-@PyGTKCallback
-class FileTab(gtk.HBox):
+class FileTab(Gtk.HBox):
+    __gsignals__ = {'error':(GObject.SignalFlags.RUN_FIRST, None, (object,)),
+                    'adjust-path-clicked':(GObject.SignalFlags.RUN_FIRST, None, (object,)),
+                    'new-clicked':(GObject.SignalFlags.RUN_FIRST, None, ()),
+                    'close-clicked':(GObject.SignalFlags.RUN_FIRST, None, ()),
+                    'quit-clicked':(GObject.SignalFlags.RUN_FIRST, None, ()),
+                    'opened':(GObject.SignalFlags.RUN_FIRST, None, (object,))
+                  }
     def __init__(self, searchpath=None):
-        gtk.HBox.__init__(self)
+        Gtk.HBox.__init__(self)
 
         self.oldexptype = None
         if searchpath is None:
@@ -18,32 +23,33 @@ class FileTab(gtk.HBox):
         self.searchpath = misc.searchpath.SearchPath(searchpath)
         self.data = None
 
-        tb = gtk.Toolbar()
+        tb = Gtk.Toolbar()
         tb.set_show_arrow(False)
-        tb.set_style(gtk.TOOLBAR_BOTH)
-        self.pack_start(tb, False, True)
-        b = gtk.ToolButton(gtk.STOCK_NEW)
+        tb.set_style(Gtk.ToolbarStyle.BOTH)
+        self.pack_start(tb, False, True, 0)
+        b = Gtk.ToolButton(Gtk.STOCK_NEW)
         tb.insert(b, -1)
         b.connect('clicked', self.on_button_clicked, 'new-clicked')
-        b = gtk.ToolButton(gtk.STOCK_CLOSE)
+        b = Gtk.ToolButton(Gtk.STOCK_CLOSE)
         tb.insert(b, -1)
         b.connect('clicked', self.on_button_clicked, 'close-clicked')
-        b = gtk.ToolButton(gtk.STOCK_QUIT)
+        b = Gtk.ToolButton(Gtk.STOCK_QUIT)
         tb.insert(b, -1)
         b.connect('clicked', self.on_button_clicked, 'quit-clicked')
-        b = gtk.ToolButton(None, "Adjust path")
-        b.set_stock_id(gtk.STOCK_DIRECTORY)
+        b = Gtk.ToolButton(Gtk.STOCK_EDIT)
+        b.set_label("Adjust path")
+        b.set_stock_id(Gtk.STOCK_DIRECTORY)
         tb.insert(b, -1)
         b.connect('clicked', self.on_button_clicked, 'adjust-path-clicked')
-        frame = gtk.Frame()
-        self.pack_start(frame, False)
-        tab = gtk.Table()
+        frame = Gtk.Frame()
+        self.pack_start(frame, False, True, 0)
+        tab = Gtk.Table()
         frame.add(tab)
 
         tablecolumn = 0
         tablerow = 0
-        l = gtk.Label('FSN:');  l.set_alignment(0, 0.5);  tab.attach(l, 2 * tablecolumn + 0, 2 * tablecolumn + 1, tablerow, tablerow + 1, gtk.FILL, gtk.FILL)
-        self.fsn_entry = gtk.SpinButton()
+        l = Gtk.Label(label='FSN:');  l.set_alignment(0, 0.5);  tab.attach(l, 2 * tablecolumn + 0, 2 * tablecolumn + 1, tablerow, tablerow + 1, Gtk.AttachOptions.FILL, Gtk.AttachOptions.FILL)
+        self.fsn_entry = Gtk.SpinButton()
         tab.attach(self.fsn_entry, 2 * tablecolumn + 1, 2 * tablecolumn + 2, tablerow, tablerow + 1)
         self.fsn_entry.set_range(0, 10000000000)
         self.fsn_entry.set_digits(0)
@@ -51,8 +57,8 @@ class FileTab(gtk.HBox):
         self.fsn_entry.set_increments(1, 10)
 
         tablerow += 1
-        l = gtk.Label('Experiment type:');  l.set_alignment(0, 0.5);  tab.attach(l, 2 * tablecolumn + 0, 2 * tablecolumn + 1, tablerow, tablerow + 1, gtk.FILL, gtk.FILL)
-        self.exptype_entry = gtk.combo_box_new_text()
+        l = Gtk.Label(label='Experiment type:');  l.set_alignment(0, 0.5);  tab.attach(l, 2 * tablecolumn + 0, 2 * tablecolumn + 1, tablerow, tablerow + 1, Gtk.AttachOptions.FILL, Gtk.AttachOptions.FILL)
+        self.exptype_entry = Gtk.ComboBoxText()
         tab.attach(self.exptype_entry, 2 * tablecolumn + 1, 2 * tablecolumn + 2, tablerow, tablerow + 1)
         self.exptype_entry.connect('changed', self.on_exptype_changed)
         self.exptype_entry.append_text('ESRF ID02')
@@ -62,29 +68,29 @@ class FileTab(gtk.HBox):
         self.exptype_entry.append_text('HDF5')
 
         tablerow += 1
-        l = gtk.Label('Filename format:');  l.set_alignment(0, 0.5);  tab.attach(l, 2 * tablecolumn + 0, 2 * tablecolumn + 1, tablerow, tablerow + 1, gtk.FILL, gtk.FILL)
-        self.filenameformat_entry = gtk.Entry()
+        l = Gtk.Label(label='Filename format:');  l.set_alignment(0, 0.5);  tab.attach(l, 2 * tablecolumn + 0, 2 * tablecolumn + 1, tablerow, tablerow + 1, Gtk.AttachOptions.FILL, Gtk.AttachOptions.FILL)
+        self.filenameformat_entry = Gtk.Entry()
         tab.attach(self.filenameformat_entry, 2 * tablecolumn + 1, 2 * tablecolumn + 2, tablerow, tablerow + 1)
 
 
         tablecolumn += 1
         tablerow = 0
-        l = gtk.Label('Mask file name:');  l.set_alignment(0, 0.5);  tab.attach(l, 2 * tablecolumn + 0, 2 * tablecolumn + 1, tablerow, tablerow + 1, gtk.FILL, gtk.FILL)
-        self.maskname_entry = gtk.Entry()
+        l = Gtk.Label(label='Mask file name:');  l.set_alignment(0, 0.5);  tab.attach(l, 2 * tablecolumn + 0, 2 * tablecolumn + 1, tablerow, tablerow + 1, Gtk.AttachOptions.FILL, Gtk.AttachOptions.FILL)
+        self.maskname_entry = Gtk.Entry()
         tab.attach(self.maskname_entry, 2 * tablecolumn + 1, 2 * tablecolumn + 2, tablerow, tablerow + 1)
 
         tablerow += 1
-        self.loadmask_checkbox = gtk.CheckButton('Load mask')
+        self.loadmask_checkbox = Gtk.CheckButton('Load mask')
         tab.attach(self.loadmask_checkbox, 2 * tablecolumn + 0, 2 * tablecolumn + 2, tablerow, tablerow + 1)
 
         tablerow += 1
-        l = gtk.Label('Headername format:');  l.set_alignment(0, 0.5);  tab.attach(l, 2 * tablecolumn + 0, 2 * tablecolumn + 1, tablerow, tablerow + 1, gtk.FILL, gtk.FILL)
-        self.headernameformat_entry = gtk.Entry()
+        l = Gtk.Label(label='Headername format:');  l.set_alignment(0, 0.5);  tab.attach(l, 2 * tablecolumn + 0, 2 * tablecolumn + 1, tablerow, tablerow + 1, Gtk.AttachOptions.FILL, Gtk.AttachOptions.FILL)
+        self.headernameformat_entry = Gtk.Entry()
         tab.attach(self.headernameformat_entry, 2 * tablecolumn + 1, 2 * tablecolumn + 2, tablerow, tablerow + 1)
 
         tablecolumn += 1
-        b = gtk.Button(stock=gtk.STOCK_OPEN)
-        b.set_image_position(gtk.POS_TOP)
+        b = Gtk.Button(stock=Gtk.STOCK_OPEN)
+        b.set_image_position(Gtk.PositionType.TOP)
         tab.attach(b, 2 * tablecolumn + 0, 2 * tablecolumn + 2, 0, 3)
         b.connect('clicked', self.on_open)
 
@@ -92,12 +98,12 @@ class FileTab(gtk.HBox):
 
 
         self.show_all()
-    def on_button_clicked(self, button, argument): #IGNORE:W0613
+    def on_button_clicked(self, button, argument):  # IGNORE:W0613
         if argument == 'adjust-path-clicked':
             pe = patheditor.PathEditor(self, self.searchpath)
             try:
                 ret = pe.run()
-                if ret == gtk.RESPONSE_OK:
+                if ret == Gtk.ResponseType.OK:
                     pe.update_search_path()
             finally:
                 pe.destroy()
@@ -119,7 +125,7 @@ class FileTab(gtk.HBox):
             self.filenameformat_entry.set_text('')
         self.oldexptype = exptype
 
-    def on_open(self, button): #IGNORE:W0613
+    def on_open(self, button):  # IGNORE:W0613
         maskname = self.maskname_entry.get_text()
         if not maskname:
             maskname = None
@@ -136,7 +142,7 @@ class FileTab(gtk.HBox):
         except IOError as ioe:
             self.emit('error', ioe)
         else:
-            gobject.idle_add(self.call_callbacks_on_open)
+            GObject.idle_add(self.call_callbacks_on_open)
         return True
     def call_callbacks_on_open(self):
         if self.data:
