@@ -1,37 +1,41 @@
-import gtk
+from gi.repository import Gtk
+from gi.repository import GObject
 import matplotlib
 from sastool import misc
 
-from ..PyGTKCallback import PyGTKCallback
-@PyGTKCallback
-class PlotTab(gtk.HBox):
+class PlotTab(Gtk.HBox):
     lastplotraw = None
+    __gsignals__ = {'error':(GObject.SignalFlags.RUN_FIRST, None, (str,)),
+                   'clear-graph':(GObject.SignalFlags.RUN_FIRST, None, ()),
+                   'refresh-graph':(GObject.SignalFlags.RUN_FIRST, None, ()),
+                   'plotparams-changed':(GObject.SignalFlags.RUN_FIRST, None, ()),
+                   }
     def __init__(self):
-        gtk.HBox.__init__(self)
-        tb = gtk.Toolbar()
+        Gtk.HBox.__init__(self)
+        tb = Gtk.Toolbar()
         tb.set_show_arrow(False)
-        tb.set_style(gtk.TOOLBAR_BOTH)
-        self.pack_start(tb, False, True)
+        tb.set_style(Gtk.ToolbarStyle.BOTH)
+        self.pack_start(tb, False, True, 0)
 
-        b = gtk.ToolButton(gtk.STOCK_CLEAR)
+        b = Gtk.ToolButton(Gtk.STOCK_CLEAR)
         tb.insert(b, -1)
         b.connect('clicked', self.on_button_clicked, 'clear-graph')
 
-        b = gtk.ToolButton(gtk.STOCK_REFRESH)
+        b = Gtk.ToolButton(Gtk.STOCK_REFRESH)
         tb.insert(b, -1)
         b.connect('clicked', self.on_button_clicked, 'refresh-graph')
 
-        frame = gtk.Frame()
-        self.pack_start(frame, False)
-        tab = gtk.Table()
+        frame = Gtk.Frame()
+        self.pack_start(frame, True, True, 0)
+        tab = Gtk.Table()
         frame.add(tab)
 
         tablecolumn = 0
         tablerow = 0
 
-        l = gtk.Label('Color scale:'); l.set_alignment(0, 0.5)
-        tab.attach(l, 2 * tablecolumn, 2 * tablecolumn + 1, tablerow, tablerow + 1, gtk.FILL, gtk.FILL)
-        self.colorscale_combo = gtk.combo_box_new_text()
+        l = Gtk.Label(label='Color scale:'); l.set_alignment(0, 0.5)
+        tab.attach(l, 2 * tablecolumn, 2 * tablecolumn + 1, tablerow, tablerow + 1, Gtk.AttachOptions.FILL, Gtk.AttachOptions.FILL)
+        self.colorscale_combo = Gtk.ComboBoxText()
         tab.attach(self.colorscale_combo, 2 * tablecolumn + 1, 2 * tablecolumn + 2, tablerow, tablerow + 1)
         self.colorscale_combo.append_text('linear')
         self.colorscale_combo.append_text('log')
@@ -40,9 +44,9 @@ class PlotTab(gtk.HBox):
         self.colorscale_combo.connect('changed', self.on_params_changed)
 
         tablerow += 1
-        l = gtk.Label('Palette:'); l.set_alignment(0, 0.5)
-        tab.attach(l, 2 * tablecolumn, 2 * tablecolumn + 1, tablerow, tablerow + 1, gtk.FILL, gtk.FILL)
-        self.palette_combo = gtk.combo_box_new_text()
+        l = Gtk.Label(label='Palette:'); l.set_alignment(0, 0.5)
+        tab.attach(l, 2 * tablecolumn, 2 * tablecolumn + 1, tablerow, tablerow + 1, Gtk.AttachOptions.FILL, Gtk.AttachOptions.FILL)
+        self.palette_combo = Gtk.ComboBoxText()
         tab.attach(self.palette_combo, 2 * tablecolumn + 1, 2 * tablecolumn + 2, tablerow, tablerow + 1)
         idx = 0
         indexfound = 0
@@ -57,7 +61,7 @@ class PlotTab(gtk.HBox):
         self.palette_combo.connect('changed', self.on_params_changed)
 
         tablerow += 1
-        self.reversepalette_checkbutton = gtk.CheckButton('Reverse palette?')
+        self.reversepalette_checkbutton = Gtk.CheckButton('Reverse palette?')
         self.reversepalette_checkbutton.set_alignment(0, 0.5)
         tab.attach(self.reversepalette_checkbutton, 2 * tablecolumn, 2 * tablecolumn + 2, tablerow, tablerow + 1)
         self.reversepalette_checkbutton.set_active(defaultpalette.endswith('_r'))
@@ -65,21 +69,21 @@ class PlotTab(gtk.HBox):
 
         tablecolumn += 1
         tablerow = 0
-        self.plotqrange_checkbutton = gtk.CheckButton('Q values on axes?')
+        self.plotqrange_checkbutton = Gtk.CheckButton('Q values on axes?')
         self.plotqrange_checkbutton.set_alignment(0, 0.5)
         tab.attach(self.plotqrange_checkbutton, 2 * tablecolumn, 2 * tablecolumn + 2, tablerow, tablerow + 1)
         self.plotqrange_checkbutton.set_active(True)
         self.plotqrange_checkbutton.connect('toggled', self.on_params_changed)
 
         tablerow += 1
-        self.plotmask_checkbutton = gtk.CheckButton('Plot mask?')
+        self.plotmask_checkbutton = Gtk.CheckButton('Plot mask?')
         self.plotmask_checkbutton.set_alignment(0, 0.5)
         tab.attach(self.plotmask_checkbutton, 2 * tablecolumn, 2 * tablecolumn + 2, tablerow, tablerow + 1)
         self.plotmask_checkbutton.set_active(True)
         self.plotmask_checkbutton.connect('toggled', self.on_params_changed)
 
         tablerow += 1
-        self.crosshair_checkbutton = gtk.CheckButton('Beam position?')
+        self.crosshair_checkbutton = Gtk.CheckButton('Beam position?')
         self.crosshair_checkbutton.set_alignment(0, 0.5)
         tab.attach(self.crosshair_checkbutton, 2 * tablecolumn, 2 * tablecolumn + 2, tablerow, tablerow + 1)
         self.crosshair_checkbutton.set_active(True)
@@ -87,39 +91,39 @@ class PlotTab(gtk.HBox):
 
         tablecolumn += 1
         tablerow = 0
-        self.drawcolorbar_checkbutton = gtk.CheckButton('Draw colorbar?')
+        self.drawcolorbar_checkbutton = Gtk.CheckButton('Draw colorbar?')
         self.drawcolorbar_checkbutton.set_alignment(0, 0.5)
         tab.attach(self.drawcolorbar_checkbutton, 2 * tablecolumn, 2 * tablecolumn + 2, tablerow, tablerow + 1)
         self.drawcolorbar_checkbutton.set_active(True)
         self.drawcolorbar_checkbutton.connect('toggled', self.on_params_changed)
 
         tablerow += 1
-        self.lowclip_checkbutton = gtk.CheckButton('Lower clip val.:'); self.lowclip_checkbutton.set_alignment(0, 0.5)
-        tab.attach(self.lowclip_checkbutton, 2 * tablecolumn, 2 * tablecolumn + 1, tablerow, tablerow + 1, gtk.FILL, gtk.FILL)
+        self.lowclip_checkbutton = Gtk.CheckButton('Lower clip val.:'); self.lowclip_checkbutton.set_alignment(0, 0.5)
+        tab.attach(self.lowclip_checkbutton, 2 * tablecolumn, 2 * tablecolumn + 1, tablerow, tablerow + 1, Gtk.AttachOptions.FILL, Gtk.AttachOptions.FILL)
         self.lowclip_checkbutton.connect('toggled', self.on_clip_toggled)
-        self.lowclip_entry = gtk.Entry()
+        self.lowclip_entry = Gtk.Entry()
         tab.attach(self.lowclip_entry, 2 * tablecolumn + 1, 2 * tablecolumn + 2, tablerow, tablerow + 1)
 
         tablerow += 1
-        self.upperclip_checkbutton = gtk.CheckButton('Upper clip val.:'); self.upperclip_checkbutton.set_alignment(0, 0.5)
-        tab.attach(self.upperclip_checkbutton, 2 * tablecolumn, 2 * tablecolumn + 1, tablerow, tablerow + 1, gtk.FILL, gtk.FILL)
+        self.upperclip_checkbutton = Gtk.CheckButton('Upper clip val.:'); self.upperclip_checkbutton.set_alignment(0, 0.5)
+        tab.attach(self.upperclip_checkbutton, 2 * tablecolumn, 2 * tablecolumn + 1, tablerow, tablerow + 1, Gtk.AttachOptions.FILL, Gtk.AttachOptions.FILL)
         self.upperclip_checkbutton.connect('toggled', self.on_clip_toggled)
-        self.upperclip_entry = gtk.Entry()
+        self.upperclip_entry = Gtk.Entry()
         tab.attach(self.upperclip_entry, 2 * tablecolumn + 1, 2 * tablecolumn + 2, tablerow, tablerow + 1)
 
         self.lowclip_checkbutton.set_active(False)
         self.upperclip_checkbutton.set_active(False)
         self.on_clip_toggled(None)
 
-    def on_button_clicked(self, button, arg): #IGNORE:W0613
+    def on_button_clicked(self, button, arg):  # IGNORE:W0613
         self.emit(arg)
-    def on_params_changed(self, widget): #IGNORE:W0613
+    def on_params_changed(self, widget):  # IGNORE:W0613
         cscale = self.palette_combo.get_active_text()
         if self.reversepalette_checkbutton.get_active():
             cscale = cscale + '_r'
         misc.sastoolrc.set('gui.sasimagegui.plot.palette', cscale)
         self.emit('plotparams-changed')
-    def on_clip_toggled(self, widget): #IGNORE:W0613
+    def on_clip_toggled(self, widget):  # IGNORE:W0613
         self.upperclip_entry.set_sensitive(self.upperclip_checkbutton.get_active())
         self.lowclip_entry.set_sensitive(self.lowclip_checkbutton.get_active())
     def update_from_data(self, data):
@@ -161,7 +165,6 @@ class PlotTab(gtk.HBox):
         except ValueError:
             self.emit('error', 'Invalid (non-numeric) max.value: ' + self.upperclip_entry.get_text())
             maxvalue = float(data.max(self.plotmask_checkbutton.get_active()))
-
         self.lastplotraw = data.plot2d(axes=axes, cmap=getattr(matplotlib.cm, palette),
                                          zscale=colorscale,
                                          drawmask=self.plotmask_checkbutton.get_active(),
